==> mx-packageinstaller-pkglist_25.12.01mx25.tar.xz: mx-packageinstaller-pkglist/steam.pm <==
<?xml version="1.0" encoding="UTF-8"?>
<app>

<category>
Games
</category>

<name>
Steam
</name>

<description>
   <am>Steam powered games</am>
   <ar>Steam powered games</ar>
   <bg>Steam powered games</bg>
   <bn>Steam powered games</bn>
   <ca>Jocs a través de Steam</ca>
   <cs>Steam powered games</cs>
   <da>Spil fra Steam</da>
   <de>Steam powered Games</de>
   <el>Παιχνίδια του Stream</el>
   <en>Steam powered games</en>
   <es>Juegos accionados por Steam</es>
   <et>Steam powered games</et>
   <eu>Steam powered games</eu>
   <fa>Steam powered games</fa>
   <fil_PH>Steam powered games</fil_PH>
   <fi>Steam-pelit</fi>
   <fr>Jeux fonctionnant avec Steam</fr>
   <he_IL>Steam powered games</he_IL>
   <hi>स्टीम चलित खेल</hi>
   <hr>Steam powered games</hr>
   <hu>Steam powered games</hu>
   <id>Steam powered games</id>
   <is>Steam powered games</is>
   <it>Giochi offerti da Steam</it>
   <ja>Steam で動くゲーム</ja>
   <kk>Steam powered games</kk>
   <ko>Steam powered games</ko>
   <lt>Steam powered games</lt>
   <mk>Steam powered games</mk>
   <mr>Steam powered games</mr>
   <nb>Steam-baserte spill</nb>
   <nl>Steam aangedreven spellen</nl>
   <pl>Gry na Steam</pl>
   <pt_BR>Jogos da Plataforma Steam</pt_BR>
   <pt>Jogos da Plataforma Steam</pt>
   <ro>Steam powered games</ro>
   <ru>Платформа цифрового распространения игр</ru>
   <sk>Steam powered games</sk>
   <sl>Steam igre</sl>
   <sq>Lojëra bazuar në Steam</sq>
   <sr>Steam powered games</sr>
   <sv>Steam-drivna spel</sv>
   <tr>Steam detekli oyunlar</tr>
   <uk>Steam powered games</uk>
   <vi>Steam powered games</vi>
   <zh_CN>Steam powered games</zh_CN>
   <zh_TW>Steam powered games</zh_TW>
</description>

<installable>
32,64
</installable>

<screenshot>https://screenshots.debian.net/shrine/screenshot/14991/simage/large-fdb68e27705c0554fa7ffc10e4ba1dc0.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
steam-installer
steam-libs
steam-libs-i386
</install_package_names>


<postinstall>
apt-get install -f
</postinstall>


<uninstall_package_names>
steam-installer
steam-libs
steam-libs-i386
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_26.02.04mx25.tar.xz: mx-packageinstaller-pkglist/steam.pm <==
<?xml version="1.0" encoding="UTF-8"?>
<app>

<category>
Games
</category>

<name>
Steam
</name>

<description>
   <am>Steam powered games</am>
   <ar>Steam powered games</ar>
   <bg>Steam powered games</bg>
   <bn>Steam powered games</bn>
   <ca>Jocs a través de Steam</ca>
   <cs>Steam powered games</cs>
   <da>Spil fra Steam</da>
   <de>Steam powered Games</de>
   <el>Παιχνίδια του Stream</el>
   <en>Steam powered games</en>
   <es>Juegos accionados por Steam</es>
   <et>Steam powered games</et>
   <eu>Steam powered games</eu>
   <fa>Steam powered games</fa>
   <fil_PH>Steam powered games</fil_PH>
   <fi>Steam-pelit</fi>
   <fr>Jeux fonctionnant avec Steam</fr>
   <he_IL>Steam powered games</he_IL>
   <hi>स्टीम चलित खेल</hi>
   <hr>Steam powered games</hr>
   <hu>Steam powered games</hu>
   <id>Steam powered games</id>
   <is>Steam powered games</is>
   <it>Giochi offerti da Steam</it>
   <ja>Steam で動くゲーム</ja>
   <kk>Steam powered games</kk>
   <ko>Steam powered games</ko>
   <lt>Steam powered games</lt>
   <mk>Steam powered games</mk>
   <mr>Steam powered games</mr>
   <nb>Steam-baserte spill</nb>
   <nl>Steam aangedreven spellen</nl>
   <pl>Gry na Steam</pl>
   <pt_BR>Jogos da Plataforma Steam</pt_BR>
   <pt>Jogos da Plataforma Steam</pt>
   <ro>Steam powered games</ro>
   <ru>Платформа цифрового распространения игр</ru>
   <sk>Steam powered games</sk>
   <sl>Steam igre</sl>
   <sq>Lojëra bazuar në Steam</sq>
   <sr>Steam powered games</sr>
   <sv>Steam-drivna spel</sv>
   <tr>Steam detekli oyunlar</tr>
   <uk>Steam powered games</uk>
   <vi>Steam powered games</vi>
   <zh_CN>Steam powered games</zh_CN>
   <zh_TW>Steam powered games</zh_TW>
</description>

<installable>
32,64
</installable>

<screenshot>https://screenshots.debian.net/shrine/screenshot/14991/simage/large-fdb68e27705c0554fa7ffc10e4ba1dc0.png</screenshot>

<preinstall>
#preinstall libs with --install-recommends to pick up a bunch of 32 bit libraries
apt-get update
#remove old libs meta packages
echo 'remove existing steam packages'
apt-get remove steam-installer steam-libs steam-libs:i386 steam-libs-i386 steam-libs-i386:i386
echo 'install new steam dependency packages'
apt-get install steam-libs steam-libs-i386 --install-recommends
</preinstall>

<install_package_names>
steam-installer
steam-libs
steam-libs-i386
</install_package_names>


<postinstall>
apt-get install -f
</postinstall>


<uninstall_package_names>
steam-installer
steam-libs
steam-libs-i386
</uninstall_package_names>
</app>
